# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-01-28 15:46
# @Author : 毛鹏

# qss_dict_11 = {
#     "theme_name": "浅紫色主题 v1.2",
#     # 主题色 - 保持与Theme类兼容
#     "primary_100": "#634c86",    # 主色（您指定的紫色）
#     "primary_200": "#c4b5fd",    # 主色（浅紫色）
#     "primary_300": "#f5f3ff",    # 主色（极浅紫色）
#     "accent_100": "#5f6a79",     # 强调色（您指定的灰蓝色）
#     "accent_200": "#8a7faf",     # 强调色（浅紫色）
#     "text_100": "#262626",       # 主要文本颜色
#     "text_200": "#525252",       # 次要文本颜色
#     "bg_100": "#ffffff",         # 背景色（纯白色）
#     "bg_200": "#f8f9fa",         # 次要背景色（极浅灰）
#     "bg_300": "#d6cfe2",         # 较深背景色（浅灰）
#     # 边距和边距颜色
#     "border": "1px solid #e9ecef",
#     "border_radius": "6px",      # 现代化圆角
#     # 字体
#     "font": {
#         "family": "'Inter', 'Segoe UI', '微软雅黑', sans-serif",  # 现代化字体
#         "title_size": 13,
#         "text_size": 11,
#         "weight": "normal"
#     },
#     # 其他颜色组，如通知、警告、成功、错误等
#     "group": {
#         "info": "#634c86",
#         "warning": "#f59e0b",
#         "success": "#22c55e",
#         "error": "#ef4444"
#     }
# }

qss_dict_1 = {
    "theme_name": "灰紫主题 v1.2",
    # 主色系 - 用于界面主要元素
    "primary_000": "#6A5A80",    # 深主色-深灰紫：用于取消按钮、次要操作
    "primary_100": "#8A7AA0",    # 主色-浅灰紫：用于确认按钮、重要标题
    "primary_200": "#D8D0EB",    # 次要主色-淡灰紫：用于悬停状态、次要元素
    "primary_300": "#F9F8FD",    # 背景主色-极淡灰紫：用于卡片背景、高亮区域

    # 强调色系 - 用于辅助元素和装饰
    "accent_100": "#7A7F89",     # 强调色-中性灰：用于图标、边框、分割线
    "accent_200": "#B0A8C5",     # 次要强调色-灰紫色：用于标签、徽章

    # 文本色系 - 确保良好的可读性
    "text_100": "#383738",       # 主要文本-深灰色：用于标题、重要文字
    "text_200": "#666666",       # 次要文本-中灰色：用于正文、描述文字

    # 背景色系 - 建立清晰的视觉层次
    "bg_100": "#FFFFFF",         # 主背景-纯白色：用于页面背景
    "bg_200": "#F8F7FC",         # 次要背景-极淡灰紫：用于卡片背景
    "bg_300": "#D5D0DE",         # 三级背景-中等灰紫：用于输入框、选中状态

    # 边框样式
    "border": "1px solid #f2f1f6",  # 边框样式-极淡灰紫边框
    "border_radius": "6px",      # 圆角大小-现代化圆角

    # 字体设置
    "font": {
        "family": "微软雅黑",  # 字体族-现代化无衬线字体
        "title_size": 13,        # 标题字号-13px
        "text_size": 11,         # 正文字号-11px
        "weight": "normal"       # 字重-常规
    },

    # 功能色系 - 用于系统状态反馈
    "group": {
        "info": "#8A7AA0",       # 信息色-与主色一致：用于信息提示
        "warning": "#E6A93C",    # 警告色-琥珀色：用于警告状态
        "success": "#38B27C",    # 成功色-绿色：用于成功状态
        "error": "#E87070"       # 错误色-红色：用于错误状态
    }
}